@@ -1,21 +1,8 @@
-/******************************************************************************
-*   Copyright 2016 David Rosca <nowrep@gmail.com>                             *
-*                                                                             *
-*   This library is free software; you can redistribute it and/or             *
-*   modify it under the terms of the GNU Library General Public               *
-*   License as published by the Free Software Foundation; either              *
-*   version 2 of the License, or (at your option) any later version.          *
-*                                                                             *
-*   This library is distributed in the hope that it will be useful,           *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU          *
-*   Library General Public License for more details.                          *
-*                                                                             *
-*   You should have received a copy of the GNU Library General Public License *
-*   along with this library; see the file COPYING.LIB.  If not, write to      *
-*   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
-*   Boston, MA 02110-1301, USA.                                               *
-*******************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2016 David Rosca <nowrep@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "iconitemtest.h"
 
@@ -33,6 +20,8 @@
 #include "plasma/theme.h"
 #include "plasma/svg.h"
 
+#include "utils.h"
+
 static bool imageIsEmpty(const QImage &img)
 {
     for (int i = 0; i < img.width(); ++i) {
@@ -47,20 +36,11 @@ static bool imageIsEmpty(const QImage &img)
 
 void IconItemTest::initTestCase()
 {
-    if (qgetenv("XDG_DATA_DIRS").isEmpty()) {
-        QWARN("\n"
-              "  !!!\n"
-              "  Switching QStandardPaths into testing mode.\n"
-              "  Make sure xdg data can be found or set XDG_DATA_DIRS.\n"
-              "  !!!\n");
-    }
+    Plasma::TestUtils::installPlasmaTheme("breeze");
+    Plasma::TestUtils::installPlasmaTheme("breeze-light");
+    Plasma::TestUtils::installPlasmaTheme("breeze-dark");
 
-    // make our theme in search path
-    qputenv("XDG_DATA_DIRS",
-            qgetenv("XDG_DATA_DIRS") + ":" + QFINDTESTDATA("data").toLocal8Bit());
-
-    // set default icon theme to test-theme
-    QStandardPaths::setTestModeEnabled(true);
+    qputenv("XDG_DATA_DIRS",  qgetenv("XDG_DATA_DIRS") + ":" + QFINDTESTDATA("data").toLocal8Bit());
 
     QString configPath = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation);
 
@@ -505,7 +485,7 @@ void IconItemTest::implicitSize()
     KIconLoader::global()->reconfigure(QString());
     // merely changing the setting and calling reconfigure won't emit this signal,
     // the KCM uses a method "newIconLoader" method which does that but it's deprecated
-    emit KIconLoader::global()->iconLoaderSettingsChanged();
+    Q_EMIT KIconLoader::global()->iconLoaderSettingsChanged();
 
     QCOMPARE(widthSpy.count(), 1);
     QCOMPARE(heightSpy.count(), 1);
