@@ -1,23 +1,9 @@
-/***************************************************************************
- *   Copyright 2010 Marco Martin <mart@kde.org>                            *
- *   Copyright 2014 David Edmundson <davidedmundson@kde.org>               *
- *                                                                         *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Marco Martin <mart@kde.org>
+    SPDX-FileCopyrightText: 2014 David Edmundson <davidedmundson@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef FRAMESVGITEM_P
 #define FRAMESVGITEM_P
 
@@ -89,6 +75,9 @@ public:
     void setFixed(bool fixed);
     bool isFixed() const;
 
+    void setInset(bool inset);
+    bool isInset() const;
+
 public Q_SLOTS:
     void update();
 
@@ -98,6 +87,7 @@ Q_SIGNALS:
 private:
     FrameSvg *m_frameSvg;
     bool m_fixed;
+    bool m_inset;
 };
 
 
@@ -120,7 +110,7 @@ class FrameSvgItem : public QQuickItem
 
     /**
      * prefix for the 9 piece svg, like "pushed" or "normal" for the button
-     * see https://techbase.kde.org/Development/Tutorials/Plasma/ThemeDetails
+     * see https://techbase.kde.org/Development/Tutorials/Plasma5/ThemeDetails
      * for a list of paths and prefixes
      * It can also be an array of strings, specifying a fallback chain in case
      * the first element isn't found in the theme, eg ["toolbutton-normal", "normal"]
@@ -148,6 +138,14 @@ class FrameSvgItem : public QQuickItem
      */
     Q_PROPERTY(QObject *fixedMargins READ fixedMargins CONSTANT)
 
+    /**
+     * The inset of the frame
+     * read only
+     * @see FrameSvgItemMargins
+     * @since 5.77
+     */
+    Q_PROPERTY(QObject *inset READ inset CONSTANT)
+
     /**
      * The borders that will be rendered, it's a flag combination of:
      *  NoBorder
@@ -214,6 +212,7 @@ public:
 
     FrameSvgItemMargins *margins();
     FrameSvgItemMargins *fixedMargins();
+    FrameSvgItemMargins *inset();
 
     void setColorGroup(Plasma::Theme::ColorGroup group);
     Plasma::Theme::ColorGroup colorGroup() const;
@@ -264,9 +263,11 @@ private:
     Plasma::FrameSvg *m_frameSvg;
     FrameSvgItemMargins *m_margins;
     FrameSvgItemMargins *m_fixedMargins;
+    FrameSvgItemMargins *m_insetMargins;
     // logged margins to check for changes
     QVector<qreal> m_oldMargins;
     QVector<qreal> m_oldFixedMargins;
+    QVector<qreal> m_oldInsetMargins;
     QStringList m_prefixes;
     bool m_textureChanged;
     bool m_sizeChanged;
